@@ -1,18 +1,17 @@
 use crate::net::{Ipv4Addr, Ipv6Addr, SocketAddr};
 use cap_primitives::{ambient_authority, AmbientAuthority};
 #[cfg(not(windows))]
+use io_extras::os::rustix::{AsRawFd, FromRawFd, IntoRawFd, RawFd};
+#[cfg(not(windows))]
 use io_lifetimes::{AsFd, BorrowedFd, FromFd, IntoFd, OwnedFd};
 #[cfg(windows)]
 use io_lifetimes::{AsSocket, BorrowedSocket, FromSocket, IntoSocket, OwnedSocket};
 use std::time::Duration;
 use std::{fmt, io, net};
-#[cfg(not(windows))]
-use unsafe_io::os::rsix::{AsRawFd, FromRawFd, IntoRawFd, RawFd};
-use unsafe_io::OwnsRaw;
 #[cfg(windows)]
 use {
+    io_extras::os::windows::{AsRawHandleOrSocket, IntoRawHandleOrSocket, RawHandleOrSocket},
     std::os::windows::io::{AsRawSocket, FromRawSocket, IntoRawSocket, RawSocket},
-    unsafe_io::os::windows::{AsRawHandleOrSocket, IntoRawHandleOrSocket, RawHandleOrSocket},
 };
 
 /// A UDP socket.
@@ -394,9 +393,6 @@ impl IntoRawHandleOrSocket for UdpSocket {
     }
 }
 
-// Safety: `UdpSocket` wraps a `net::UdpSocket` which owns its handle.
-unsafe impl OwnsRaw for UdpSocket {}
-
 impl fmt::Debug for UdpSocket {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         self.std.fmt(f)
